StreamExt

Trait StreamExt 

pub trait StreamExt: Stream {
    // Provided methods
    fn lend(self) -> Lend<Self>
       where Self: Sized + Unpin { ... }
    fn lend_mut(self) -> LendMut<Self>
       where Self: Sized + Unpin { ... }
}
An extension for the Stream trait

Provided Methods

fn lend(self) -> Lend<Self>
where Self: Sized + Unpin,

Creates a stream which yields a reference to self as well as the next value.

fn lend_mut(self) -> LendMut<Self>
where Self: Sized + Unpin,

Creates a stream which yields a mutable reference to self as well as the next value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S: Stream> StreamExt for S